/**
 * Creating a sidebar enables you to:
 - create an ordered group of docs
 - render a sidebar for each doc of that group
 - provide next/previous navigation

 The sidebars can be generated from the filesystem, or explicitly defined here.

 Create as many sidebars as you want.
 */

// @ts-check

/** @type {import('@docusaurus/plugin-content-docs').SidebarsConfig} */
const sidebars = {
  // By default, Docusaurus generates a sidebar from the docs folder structure
  //tutorialSidebar: [{ type: 'autogenerated', dirName: '.' }],
  // But you can create a sidebar manually
  sidebar: [
    {
      type: 'doc',
      label: 'Intro',
      id: 'intro',
    },
    {
      type: 'doc',
      label: 'Resources',
      id: 'Resources',
    },
    {
      type: 'doc',
      label: 'Liquidity Program',
      id: 'Liquidity Program',
    },
    {
      type: 'doc',
      label: 'IPT Sale',
      id: 'IPTsale',
    },
    {
      type: 'category',
      collapsed: false,
      label: 'Concepts',
      link: { type: 'doc', id: 'concepts/index' },
      items: [
        {
          type: 'autogenerated',
          dirName: 'concepts',
        },
      ],
    },
    {
      type: 'category',
      label: 'Guides',
      collapsed: false,
      link: { type: 'generated-index', description: 'guides' },
      items: [
        {
          type: 'autogenerated',
          dirName: 'guides',
        },
      ],
    },
    {
      type: 'category',
      label: 'Reference',
      collapsed: false,
      link: { type: 'doc', id: 'reference/index' },
      items: [
        {
          type: 'doc',
          label: 'Deployed Contracts',
          id: 'reference/DeployedContracts',
        },
        {
          type: 'doc',
          label: 'Protocol Parameters',
          id: 'reference/ProtocolParameters',
        },
        {
          type: 'category',
          label: 'Core',
          collapsed: true,
          link: { type: 'generated-index', description: 'core contracts' },
          items: [
            {
              type: 'autogenerated',
              dirName: 'reference/Core',
            },
          ],
        },
        {
          type: 'category',
          label: 'Periphery',
          collapsed: true,
          link: { type: 'generated-index', description: 'periphery contracts' },
          items: [
            {
              type: 'doc',
              label: 'Oracle Master',
              id: 'reference/Periphery/OracleMaster',
            },
            {
              type: 'doc',
              label: 'Anchor Oracle Relay',
              id: 'reference/Periphery/AnchorOracleRelay',
            },
            {
              type: 'doc',
              label: 'Chainlink Oracle Relay',
              id: 'reference/Periphery/ChainlinkOracleRelay',
            },
            {
              type: 'doc',
              label: 'Uniswap V3 Oracle Relay',
              id: 'reference/Periphery/UniswapV3OracleRelay',
            },
            {
              type: 'doc',
              label: 'Curve Master',
              id: 'reference/Periphery/CurveMaster',
            },
            {
              type: 'doc',
              label: 'Three Lines 0_100',
              id: 'reference/Periphery/ThreeLines0_100',
            },
            {
              type: 'doc',
              label: 'Liquidator',
              id: 'reference/Periphery/Liquidator',
            },
          ],
        },
        {
          type: 'category',
          label: 'Governance',
          collapsed: true,
          link: {
            type: 'generated-index',
            description: 'governance contracts',
          },
          items: [
            {
              type: 'autogenerated',
              dirName: 'reference/Governance',
            },
          ],
        },
        {
          type: 'category',
          label: 'Token',
          collapsed: true,
          link: { type: 'generated-index', description: 'token contracts' },
          items: [
            {
              type: 'autogenerated',
              dirName: 'reference/Token',
            },
          ],
        },
      ],
    },
  ],
}

module.exports = sidebars
